'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var jsonPlugin = _interopDefault(require('@rollup/plugin-json'));
var fs = require('fs');
var path = require('path');

var branchRegexp = /ref: .*\/(\w*)/;
var shortRegexp = /0000000000000000000000000000000000000000 ([0-9a-f]{8})/;
var dirRegexp = /(.*)[\/\\]?package.json/;

function version(options) {
	var jsonTransformer = jsonPlugin(options).transform;

	return {
		name: "git-version",

		transform: function transform(json, id) {
			if (id.indexOf("node_modules") === -1 && id.match(/package\.json$/)) {
				var dir = dirRegexp.exec(id)[1];
				var parsed = JSON.parse(json);

				try {
					// Read some files in the ".git" subdirectory
					// The technique should be OS-agnostic enough
					var data1 = fs.readFileSync(path.join(dir, ".git/HEAD"));
					var branch = branchRegexp.exec(data1)[1];

					var data2 = fs.readFileSync(path.join(dir, ".git/logs/HEAD"));
					var short = shortRegexp.exec(data2)[1];

					parsed.version += "+" + branch + "." + short;
				} catch (ex) {
					// An exception might happen when the git info was not found
					// (i.e. no ".git" subdirectory, weird filesystem or git install)
					// or if the format of the files is unrecognized.
					// The fallback is to return the package.json file unmodified

					console.warn(
						("git-version plugin couldn't parse git information from " + dir)
					);
				}

				return jsonTransformer(JSON.stringify(parsed), id);
			} else {
				return null;
			}
		},
	};
}

module.exports = version;
